Struct
IpuzNonogramClue
Description [src]
struct IpuzNonogramClue {
guint count;
gchar* group;
}
A data type used by IpuzNonogram to indicate a segment of
a clue array in a nonogram.
For monochromatic nonograms, the group field can be safely ignored.
Structure members
count:guintNumber of cells in a row that this segment refers to.
group:gchar*Group that this segment belongs to.